<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="bo">
<context>
    <name>EngineDevice</name>
    <message>
        <location filename="../enginedevice.cpp" line="111"/>
        <source>yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="111"/>
        <source>no</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="146"/>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="146"/>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="524"/>
        <source>Unknown time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="530"/>
        <location filename="../enginedevice.cpp" line="551"/>
        <source>minute</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="532"/>
        <location filename="../enginedevice.cpp" line="553"/>
        <source>minutes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="543"/>
        <location filename="../enginedevice.cpp" line="555"/>
        <source>hour</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="545"/>
        <location filename="../enginedevice.cpp" line="557"/>
        <source>hours</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="610"/>
        <source>Left %1h %2m (%3%)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="623"/>
        <source>charging (%1%)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="699"/>
        <source>AC adapter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="604"/>
        <source>%1% available, charged</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="612"/>
        <source>%1% available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="621"/>
        <source>Left %1h %2m to full</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="629"/>
        <source>%1 waiting to discharge (%2%)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="635"/>
        <source>%1 waiting to charge (%2%)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="703"/>
        <source>Laptop battery</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="707"/>
        <source>UPS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="711"/>
        <source>Monitor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="715"/>
        <source>Mouse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="719"/>
        <source>Keyboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="723"/>
        <source>PDA</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="727"/>
        <source>Cell phone</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="731"/>
        <source>Media player</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="735"/>
        <source>Tablet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="739"/>
        <source>Computer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../enginedevice.cpp" line="743"/>
        <source>unrecognised</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PowerTray</name>
    <message>
        <location filename="../powertray.cpp" line="111"/>
        <source>SetPower</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>S:</name>
    <message>
        <location filename="enginedevice.cpp" line="826"/>
        <source></source>
        <comment>tablet device</comment>
        <translation></translation>
    </message>
</context>
<context>
    <name>powerwindow</name>
    <message>
        <location filename="../powerwindow.cpp" line="134"/>
        <location filename="../powerwindow.cpp" line="267"/>
        <source>Charging</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerwindow.cpp" line="262"/>
        <source>Left %1h 
 %2m</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerwindow.cpp" line="264"/>
        <source>Discharging</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerwindow.cpp" line="270"/>
        <source>fully charged</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerwindow.cpp" line="298"/>
        <location filename="../powerwindow.cpp" line="312"/>
        <location filename="../powerwindow.cpp" line="326"/>
        <location filename="../powerwindow.cpp" line="343"/>
        <location filename="../powerwindow.cpp" line="357"/>
        <location filename="../powerwindow.cpp" line="372"/>
        <source>Power Manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerwindow.cpp" line="298"/>
        <source>charge notification</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerwindow.cpp" line="299"/>
        <source>battery is charging</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerwindow.cpp" line="312"/>
        <source>discharged notification</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerwindow.cpp" line="313"/>
        <source>battery is discharging</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerwindow.cpp" line="329"/>
        <source>fullly charged notification</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerwindow.cpp" line="329"/>
        <source>battery is fullly charged</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerwindow.cpp" line="343"/>
        <source>low battery notification</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerwindow.cpp" line="344"/>
        <source>battery is low, please plug in power</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerwindow.cpp" line="358"/>
        <source>critical battery notification</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerwindow.cpp" line="358"/>
        <source>battery is critical low,please plug in!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerwindow.cpp" line="372"/>
        <source>operation notification</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerwindow.cpp" line="373"/>
        <source>performing low power operation</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>settinglabel</name>
    <message>
        <location filename="../powerwindow.cpp" line="511"/>
        <source>PowerSet</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
